import 'package:flutter/material.dart';
import '../services/database_helper.dart';
import '../models/product.dart';
import 'add_edit_product_screen.dart';

class ProductListScreen extends StatefulWidget {
  const ProductListScreen({super.key});

  @override
  State<ProductListScreen> createState() => _ProductListScreenState();
}

class _ProductListScreenState extends State<ProductListScreen> {
  late DatabaseHelper _databaseHelper;
  List<Product> _products = [];
  bool _isLoading = true;

  @override
  void initState() {
    super.initState();
    _databaseHelper = DatabaseHelper();
    _loadProducts();
  }

  Future<void> _loadProducts() async {
    setState(() {
      _isLoading = true;
    });
    final products = await _databaseHelper.getProducts();
    if (!mounted) return;
    setState(() {
      _products = products;
      _isLoading = false;
    });
  }

  Future<void> _deleteProduct(int id) async {
    await _databaseHelper.deleteProduct(id);
    _loadProducts();
  }

  void _navigateToAddEditProduct([Product? product]) async {
    final result = await Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) => AddEditProductScreen(product: product),
      ),
    );

    if (!mounted) return;
    if (result == true) {
      _loadProducts();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('لیست کالاها'), centerTitle: true),
      body:
          _isLoading
              ? const Center(child: CircularProgressIndicator())
              : _products.isEmpty
              ? const Center(
                child: Text(
                  'هیچ کالایی یافت نشد. برای شروع، یک کالا اضافه کنید.',
                ),
              )
              : ListView.builder(
                itemCount: _products.length,
                itemBuilder: (context, index) {
                  final product = _products[index];
                  return Card(
                    margin: const EdgeInsets.symmetric(
                      horizontal: 10,
                      vertical: 5,
                    ),
                    child: ListTile(
                      leading: CircleAvatar(
                        child: Text(product.quantity.toString()),
                      ),
                      title: Text(product.name),
                      subtitle: Text(
                        'کد: ${product.code} | قیمت: ${product.price} تومان',
                      ),
                      trailing: Row(
                        mainAxisSize: MainAxisSize.min,
                        children: [
                          IconButton(
                            icon: const Icon(Icons.edit, color: Colors.blue),
                            onPressed: () => _navigateToAddEditProduct(product),
                          ),
                          IconButton(
                            icon: const Icon(Icons.delete, color: Colors.red),
                            onPressed: () {
                              showDialog(
                                context: context,
                                builder:
                                    (context) => AlertDialog(
                                      title: const Text('حذف کالا'),
                                      content: Text(
                                        'آیا مطمئنید که می‌خواهید ${product.name} را حذف کنید؟',
                                      ),
                                      actions: [
                                        TextButton(
                                          onPressed:
                                              () => Navigator.pop(context),
                                          child: const Text('خیر'),
                                        ),
                                        TextButton(
                                          onPressed: () {
                                            _deleteProduct(product.id!);
                                            if (!mounted)
                                              return; // Add this check
                                            Navigator.pop(context);
                                          },
                                          child: const Text('بله'),
                                        ),
                                      ],
                                    ),
                              );
                            },
                          ),
                        ],
                      ),
                      onTap: () {
                        _navigateToAddEditProduct(product);
                      },
                    ),
                  );
                },
              ),
      floatingActionButton: FloatingActionButton(
        onPressed: () => _navigateToAddEditProduct(),
        child: const Icon(Icons.add),
      ),
    );
  }
}
